@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -328,8 +328,10 @@ cur_title_get_chapter_bounds (GstDvdReadSrc * src, gint chapter,
 
   *p_first_cell = pgc->program_map[pgn - 1] - 1;
 
+  /* last cell is used as a 'up to boundary', not 'up to and including',
+   * i.e. it is the first cell not included in the chapter range */
   if (chapter == (src->num_chapters - 1)) {
-    *p_last_cell = pgc->nr_of_cells - 1;
+    *p_last_cell = pgc->nr_of_cells;
   } else {
     pgn_next_ch = src->vts_ptt_srpt->title[src->ttn - 1].ptt[chapter + 1].pgn;
     *p_last_cell = pgc->program_map[pgn_next_ch - 1] - 1;
