@@ -81,9 +81,11 @@ static void gst_mpeg2dec_finalize (GObject * object);
 /* GstVideoDecoder base class method */
 static gboolean gst_mpeg2dec_open (GstVideoDecoder * decoder);
 static gboolean gst_mpeg2dec_close (GstVideoDecoder * decoder);
+static gboolean gst_mpeg2dec_start (GstVideoDecoder * decoder);
+static gboolean gst_mpeg2dec_stop (GstVideoDecoder * decoder);
 static gboolean gst_mpeg2dec_set_format (GstVideoDecoder * decoder,
     GstVideoCodecState * state);
-static gboolean gst_mpeg2dec_reset (GstVideoDecoder * decoder, gboolean hard);
+static gboolean gst_mpeg2dec_flush (GstVideoDecoder * decoder);
 static GstFlowReturn gst_mpeg2dec_finish (GstVideoDecoder * decoder);
 static GstFlowReturn gst_mpeg2dec_handle_frame (GstVideoDecoder * decoder,
     GstVideoCodecFrame * frame);
@@ -114,7 +116,9 @@ gst_mpeg2dec_class_init (GstMpeg2decClass * klass)
 
   video_decoder_class->open = GST_DEBUG_FUNCPTR (gst_mpeg2dec_open);
   video_decoder_class->close = GST_DEBUG_FUNCPTR (gst_mpeg2dec_close);
-  video_decoder_class->reset = GST_DEBUG_FUNCPTR (gst_mpeg2dec_reset);
+  video_decoder_class->start = GST_DEBUG_FUNCPTR (gst_mpeg2dec_start);
+  video_decoder_class->stop = GST_DEBUG_FUNCPTR (gst_mpeg2dec_stop);
+  video_decoder_class->flush = GST_DEBUG_FUNCPTR (gst_mpeg2dec_flush);
   video_decoder_class->set_format = GST_DEBUG_FUNCPTR (gst_mpeg2dec_set_format);
   video_decoder_class->handle_frame =
       GST_DEBUG_FUNCPTR (gst_mpeg2dec_handle_frame);
@@ -194,25 +198,43 @@ gst_mpeg2dec_set_format (GstVideoDecoder * decoder, GstVideoCodecState * state)
 }
 
 static gboolean
-gst_mpeg2dec_reset (GstVideoDecoder * decoder, gboolean hard)
+gst_mpeg2dec_start (GstVideoDecoder * decoder)
 {
   GstMpeg2dec *mpeg2dec = GST_MPEG2DEC (decoder);
 
-  GST_DEBUG_OBJECT (mpeg2dec, "%s", hard ? "hard" : "soft");
-
-  /* reset the initial video state */
   mpeg2dec->discont_state = MPEG2DEC_DISC_NEW_PICTURE;
-  mpeg2_reset (mpeg2dec->decoder, hard);
+
+  return TRUE;
+}
+
+static gboolean
+gst_mpeg2dec_stop (GstVideoDecoder * decoder)
+{
+  GstMpeg2dec *mpeg2dec = GST_MPEG2DEC (decoder);
+
+  mpeg2_reset (mpeg2dec->decoder, 0);
   mpeg2_skip (mpeg2dec->decoder, 1);
 
   gst_mpeg2dec_clear_buffers (mpeg2dec);
 
-  if (hard) {
-    if (mpeg2dec->input_state) {
-      gst_video_codec_state_unref (mpeg2dec->input_state);
-      mpeg2dec->input_state = NULL;
-    }
-  }
+  if (mpeg2dec->input_state)
+    gst_video_codec_state_unref (mpeg2dec->input_state);
+  mpeg2dec->input_state = NULL;
+
+  return TRUE;
+}
+
+static gboolean
+gst_mpeg2dec_flush (GstVideoDecoder * decoder)
+{
+  GstMpeg2dec *mpeg2dec = GST_MPEG2DEC (decoder);
+
+  /* reset the initial video state */
+  mpeg2dec->discont_state = MPEG2DEC_DISC_NEW_PICTURE;
+  mpeg2_reset (mpeg2dec->decoder, 1);
+  mpeg2_skip (mpeg2dec->decoder, 1);
+
+  gst_mpeg2dec_clear_buffers (mpeg2dec);
 
   return TRUE;
 }
@@ -384,6 +406,13 @@ gst_mpeg2dec_alloc_sized_buf (GstMpeg2dec * mpeg2dec, guint size,
   state = gst_video_decoder_get_output_state (GST_VIDEO_DECODER (mpeg2dec));
 
   if (!mpeg2dec->need_cropping || mpeg2dec->has_cropping) {
+    /* need parsed input, but that might be slightly bogus,
+     * so avoid giving up altogether and mark it as error */
+    if (frame->output_buffer) {
+      gst_buffer_replace (&frame->output_buffer, NULL);
+      GST_VIDEO_DECODER_ERROR (mpeg2dec, 1, STREAM, DECODE,
+          ("decoding error"), ("Input not correctly parsed"), ret);
+    }
     ret =
         gst_video_decoder_allocate_output_frame (GST_VIDEO_DECODER (mpeg2dec),
         frame);
@@ -983,7 +1012,7 @@ gst_mpeg2dec_handle_frame (GstVideoDecoder * decoder,
           GST_VIDEO_DECODER_ERROR (decoder, 1, STREAM, DECODE,
               ("decoding error"), ("Bad sequence header"), ret);
           gst_video_decoder_drop_frame (decoder, frame);
-          gst_mpeg2dec_reset (decoder, FALSE);
+          gst_mpeg2dec_flush (decoder);
           goto done;
         }
         break;
