@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -691,7 +691,7 @@ gst_send_subtitle_frame (GstDvdSubDec * dec, GstClockTime end_ts)
   }
 
   out_buf =
-      gst_buffer_new_allocate (NULL, 4 * GST_VIDEO_INFO_SIZE (&dec->info),
+      gst_buffer_new_allocate (NULL, GST_VIDEO_INFO_SIZE (&dec->info),
       &params);
   gst_video_frame_map (&frame, &dec->info, out_buf, GST_MAP_READWRITE);
 
