@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <gst/check/gstcheck.h>
@@ -75,7 +75,7 @@ setup_amrnbenc (void)
       "could not set to playing");
 
   caps = gst_caps_from_string (SRC_CAPS);
-  fail_unless (gst_pad_set_caps (srcpad, caps));
+  gst_check_setup_events (srcpad, amrnbenc, caps, GST_FORMAT_TIME);
   gst_caps_unref (caps);
 
   buffers = NULL;
